# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tasks_fields.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12tasks_fields.proto\x12\x19\x61rmonik.api.grpc.v1.tasks\"R\n\x10TaskSummaryField\x12>\n\x05\x66ield\x18\x01 \x01(\x0e\x32/.armonik.api.grpc.v1.tasks.TaskSummaryEnumField\"P\n\x0fTaskOptionField\x12=\n\x05\x66ield\x18\x01 \x01(\x0e\x32..armonik.api.grpc.v1.tasks.TaskOptionEnumField\"\'\n\x16TaskOptionGenericField\x12\r\n\x05\x66ield\x18\x01 \x01(\t\"\x80\x02\n\tTaskField\x12I\n\x12task_summary_field\x18\x01 \x01(\x0b\x32+.armonik.api.grpc.v1.tasks.TaskSummaryFieldH\x00\x12G\n\x11task_option_field\x18\x02 \x01(\x0b\x32*.armonik.api.grpc.v1.tasks.TaskOptionFieldH\x00\x12V\n\x19task_option_generic_field\x18\x03 \x01(\x0b\x32\x31.armonik.api.grpc.v1.tasks.TaskOptionGenericFieldH\x00\x42\x07\n\x05\x66ield*\xd9\x05\n\x14TaskSummaryEnumField\x12\'\n#TASK_SUMMARY_ENUM_FIELD_UNSPECIFIED\x10\x00\x12#\n\x1fTASK_SUMMARY_ENUM_FIELD_TASK_ID\x10\x10\x12&\n\"TASK_SUMMARY_ENUM_FIELD_SESSION_ID\x10\x01\x12(\n$TASK_SUMMARY_ENUM_FIELD_OWNER_POD_ID\x10\t\x12+\n\'TASK_SUMMARY_ENUM_FIELD_INITIAL_TASK_ID\x10\n\x12\"\n\x1eTASK_SUMMARY_ENUM_FIELD_STATUS\x10\x02\x12&\n\"TASK_SUMMARY_ENUM_FIELD_CREATED_AT\x10\x03\x12(\n$TASK_SUMMARY_ENUM_FIELD_SUBMITTED_AT\x10\x0b\x12&\n\"TASK_SUMMARY_ENUM_FIELD_STARTED_AT\x10\x04\x12$\n TASK_SUMMARY_ENUM_FIELD_ENDED_AT\x10\x05\x12\x34\n0TASK_SUMMARY_ENUM_FIELD_CREATION_TO_END_DURATION\x10\x06\x12\x36\n2TASK_SUMMARY_ENUM_FIELD_PROCESSING_TO_END_DURATION\x10\x07\x12#\n\x1fTASK_SUMMARY_ENUM_FIELD_POD_TTL\x10\x0c\x12(\n$TASK_SUMMARY_ENUM_FIELD_POD_HOSTNAME\x10\r\x12\'\n#TASK_SUMMARY_ENUM_FIELD_RECEIVED_AT\x10\x0e\x12\'\n#TASK_SUMMARY_ENUM_FIELD_ACQUIRED_AT\x10\x0f\x12!\n\x1dTASK_SUMMARY_ENUM_FIELD_ERROR\x10\x08*\xc3\x03\n\x13TaskOptionEnumField\x12&\n\"TASK_OPTION_ENUM_FIELD_UNSPECIFIED\x10\x00\x12\'\n#TASK_OPTION_ENUM_FIELD_MAX_DURATION\x10\x01\x12&\n\"TASK_OPTION_ENUM_FIELD_MAX_RETRIES\x10\x02\x12#\n\x1fTASK_OPTION_ENUM_FIELD_PRIORITY\x10\x03\x12\'\n#TASK_OPTION_ENUM_FIELD_PARTITION_ID\x10\x04\x12+\n\'TASK_OPTION_ENUM_FIELD_APPLICATION_NAME\x10\x05\x12.\n*TASK_OPTION_ENUM_FIELD_APPLICATION_VERSION\x10\x06\x12\x30\n,TASK_OPTION_ENUM_FIELD_APPLICATION_NAMESPACE\x10\x07\x12.\n*TASK_OPTION_ENUM_FIELD_APPLICATION_SERVICE\x10\x08\x12&\n\"TASK_OPTION_ENUM_FIELD_ENGINE_TYPE\x10\tB\x1c\xaa\x02\x19\x41rmoniK.Api.gRPC.V1.Tasksb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tasks_fields_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\031ArmoniK.Api.gRPC.V1.Tasks'
  _globals['_TASKSUMMARYENUMFIELD']._serialized_start=516
  _globals['_TASKSUMMARYENUMFIELD']._serialized_end=1245
  _globals['_TASKOPTIONENUMFIELD']._serialized_start=1248
  _globals['_TASKOPTIONENUMFIELD']._serialized_end=1699
  _globals['_TASKSUMMARYFIELD']._serialized_start=49
  _globals['_TASKSUMMARYFIELD']._serialized_end=131
  _globals['_TASKOPTIONFIELD']._serialized_start=133
  _globals['_TASKOPTIONFIELD']._serialized_end=213
  _globals['_TASKOPTIONGENERICFIELD']._serialized_start=215
  _globals['_TASKOPTIONGENERICFIELD']._serialized_end=254
  _globals['_TASKFIELD']._serialized_start=257
  _globals['_TASKFIELD']._serialized_end=513
# @@protoc_insertion_point(module_scope)
